## This is the about pages

<p>
  <img src="https://travis-ci.org/connorferster/handcalcs.svg?branch=master">
<a href='https://coveralls.io/github/connorferster/handcalcs?branch=master'><img src='https://coveralls.io/repos/github/connorferster/handcalcs/badge.svg?branch=master' alt='Coverage Status' /></a>
  <img src="https://img.shields.io/badge/code%20style-black-000000.svg">
  <img src="https://img.shields.io/pypi/v/handcalcs">
  <img src="https://img.shields.io/pypi/pyversions/handcalcs">
  <img src="https://img.shields.io/github/license/connorferster/handcalcs">
  <img src="https://img.shields.io/pypi/dm/handcalcs">
</p>
<p align="center">
  <img src="../images/handcalcs.jpg"><br>
  Covert art by <a href = "https://www.instagram.com/joshuahoibergtattoos/">Joshua Hoiberg</a>
</p>